@@ -1,18 +1,18 @@
 import json
-from uuid import uuid4
-from typing import Any, Optional
 from base64 import b64decode, b64encode
+from typing import Any, Optional
+from uuid import uuid4
 
 import itsdangerous
 from itsdangerous.exc import BadTimeSignature, SignatureExpired
-
 from starlette.applications import Starlette
 from starlette.datastructures import MutableHeaders, Secret
+from starlette.middleware.sessions import \
+    SessionMiddleware as BaseSessionMiddleware
 from starlette.requests import HTTPConnection
 from starlette.types import ASGIApp, Message, Receive, Scope, Send
-from starlette.middleware.sessions import SessionMiddleware as BaseSessionMiddleware
 
-from starlette_session.backends import RedisSessionBackend, BackendType
+from starlette_session.backends import BackendType, RedisSessionBackend
 from starlette_session.interfaces import ISessionBackend
 
 
@@ -20,7 +20,6 @@ class UnknownPredefinedBackend(Exception):
     pass
 
 
-
 class SessionMiddleware:
     def __init__(
         self,
